@@ -1,5 +1,6 @@
 import * as util from "util";
 import * as pathToRegexp from "./index";
+import { gte } from "semver";
 
 type Test = [
   pathToRegexp.Path,
@@ -2594,6 +2595,95 @@ const TESTS: Test[] = [
   ]
 ];
 
+/**
+ * Named capturing groups (available from Node version 10)
+ */
+if (gte(process.version, "10.0.0")) {
+  TESTS.push(
+    [
+      /\/(?<groupname>.+)/,
+      undefined,
+      [
+        {
+          name: "groupname",
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        }
+      ],
+      [
+        ["/", null],
+        ["/foo", ["/foo", "foo"]]
+      ],
+      []
+    ],
+    [
+      /\/(?<test>.*).(?<format>html|json)/,
+      undefined,
+      [
+        {
+          name: "test",
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        },
+        {
+          name: "format",
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        }
+      ],
+      [
+        ["/route", null],
+        ["/route.txt", null],
+        ["/route.html", ["/route.html", "route", "html"]],
+        ["/route.json", ["/route.json", "route", "json"]]
+      ],
+      []
+    ],
+    [
+      /\/(.+)\/(?<groupname>.+)\/(.+)/,
+      undefined,
+      [
+        {
+          name: 0,
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        },
+        {
+          name: "groupname",
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        },
+        {
+          name: 1,
+          prefix: "",
+          suffix: "",
+          modifier: "",
+          pattern: ""
+        }
+      ],
+      [
+        ["/test", null],
+        ["/test/testData", null],
+        [
+          "/test/testData/extraStuff",
+          ["/test/testData/extraStuff", "test", "testData", "extraStuff"]
+        ]
+      ],
+      []
+    ]
+  );
+}
+
 /**
  * Dynamically generate the entire test suite.
  */
